/**
 * @fileOverview Appspresso Admob Plugin
 * @author sangchan
 * @version 1.0
 */
(function(){
    /**
     * Admob Plugin API - Admob 광고 제어.<br>
     * http://www.admob.com/ 에서 발급 받은 "Publisher ID"가 필요.<br>
     *
     * @namespace
     * @name com.appspresso.plugin.admob
     */
	
    /**
     * showAdmob 호출 시 옵션 파라미터로 사용될 객체. 광고 크기 및 화면상의 위치 지정을 위한 옵션.
     * 
     * @class
     * @name ShowAdmobOpts
     * @memberOf com.appspresso.plugin.admob
     * @property {number} position 광고 위치 - position이 지정된 경우 top/left 옵션은 무시 됨. <br/>
     * 1: top, 2: bottom
     * @property {number} top 상단 여백
     * @property {number} left 좌측 여백
     * @property {number} type 광고타입 - admob 개발자 문서상에 정해진 광고의 사이즈를 지정하는 옵션. <br/>
     * 0: 스마트 배너 사이즈 , 1: 320*50 , 2: 300*200 , 3: 468*60, 4 : 728*90 
     * @memberOf com.appspresso.plugin.admob
     */

    /**
     * Admob 배너를 생성하고 보여 줌.
     *
     * @param {AdmobSuccessCallback} scb 
     * @param {ErrorCallback} ecb
     * @param {string} pubId
     * @param {ax.ext.admob.ShowAdmobOpts} opts 광고 크기 및 화면상의 위치 지정을 위한 옵션 (optional; default:top of screen)
     * @methodOf com.appspresso.plugin.admob
     * 
     * @example
     * // default position (bottom of screen)
     * var pubID = 'a14eba45e8a8d39';
     * com.appspresso.plugin.admob.showAdmob(scb,ecb,pubID);
     * 
     * // 상단 200px 부터 광고 출력
     * ax.ext.admob.showAdmob(pubID, {'top': 200});
     */
    function showAdmob(scb, ecb, pubId, opts) {
        this.execAsync('showAdmob', scb, ecb, [ pubId || '', opts || {} ]);
    }

    /**
     * Admob 베너 제거.
     *
     * @methodOf com.appspresso.plugin.admob
     * 
     * @example
     * com.appspresso.plugin.hideAdmob(scb,ecb);
     */
    function hideAdmob() {
        this.execAsync('hideAdmob', ax.nop, ax.nop, []);
    }
    
    /**
     * Admob 배너를 새로고침 함.
     *
     * @param {AdmobSuccessCallback} scb 
     * @param {ErrorCallback} ecb
     * @methodOf com.appspresso.plugin.admob
     * 
     * @example
     * com.appspresso.plugin.admob.refreshAdmob(scb,ecb);
     */
    function refreshAdmob() {
        this.execAsync('refreshAdmob', ax.nop, ax.nop, []);
    }

	window.admobPlugin = ax.plugin('com.appspresso.plugin.admob', {
		'showAdmob': showAdmob,
		'hideAdmob': hideAdmob,
		'refreshAdmob':refreshAdmob
	},'com.appspresso.plugin.admob');
})();

/**
 * 배너광고에 대한 성공 콜백 함수를 정의합니다.
 * <p>이 콜백 인터페이스는 매개변수로 광고배너의 width 와 height를 전달 받는 성공 콜백 함수를 정의합니다. <br/>
 * 이 콜백 함수는 showAdmob,hideAdmob 과 refreshAdmob 함수에서 비동기 연산의 결과를 처리하기 위해 사용됩니다.</p> 
 * @namespace
 * @name AdmobSuccessCallback
 */

/**
 * <p>
 * 비동기 호출이 성공한 경우 호출됩니다.
 * </p> 
 * @function
 * @name onsuccess
 * @param {admob} 광고 배너의 사이즈를 리턴합니다. width, height 멤버 변수를 가지고 있습니다. 
 * @return {void}
 * @memberOf AdmobSuccessCallback
 */

